biapol\_utilities.label.intersection\_over\_union\_matrix
=========================================================

.. currentmodule:: biapol_utilities.label

.. autofunction:: intersection_over_union_matrix